===============
Columns / names
===============

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Expr.alias
    Expr.exclude
    Expr.keep_name
    Expr.map_alias
    Expr.prefix
    Expr.suffix

.. toctree::
   :maxdepth: 2
   :hidden:

   col
